/upload — GNS3 1.3.dev1 documentation

### Navigation

- index
- previous |
- GNS3 1.3.dev1 documentation »
- Upload »

# /upload

Contents

- /upload
  - GET /upload
    - Response status codes
  - POST /upload
    - Response status codes

## GET /upload

Manage upload of GNS3 images

### Response status codes

- 200: OK

## POST /upload

Manage upload of GNS3 images

### Response status codes

- 200: OK

### Navigation

- index
- previous |
- GNS3 1.3.dev1 documentation »
- Upload »